# Pull request Templates

These templates need to be used with a **query parameter** in the URL when creating a new pull request. 
For example, to use the **new plot** template, you should use the following URL:

```
https://github.com/Multiomics-Analytics-Group/vuecore/compare/main...my-branch?quick_pull=1&template=new_plot.md
````

See the [GitHub documentation](https://docs.github.com/en/communities/using-templates-to-encourage-useful-issues-and-pull-requests/creating-a-pull-request-template-for-your-repository) for more information.